/*+
    Name:	vgatest.h
    Date:	26-Aug-1988
    Author:	Kent J. Quirk
    Abstract:	This routine contains declarations for all the functions
		used in vgatest.
-*/

#define ESC 27
#define SEC *18 		/* trick for pausekey */
#define QUICK_PAUSE 6
#define NORMAL 7		/* white on black attribute in all modes */
#define BRIGHT 8		/* add this to intensify */

typedef struct {
    BYTE video_mode;
    BYTE num_rows;
    BYTE num_cols;
    BYTE max_pages;
    BYTE isgraphics;
    BYTE ismono;
    BYTE far *buf_address;
    WORD pagesize;
    WORD num_colors;
    WORD num_xpixels;
    WORD num_ypixels;
} VIDMODE;

extern VIDMODE valid_modes[];

#define COLORTEXT 3	    /* offset in table of 16-color text mode */
#define MONOGRAPH 10
#define COLOR16   11	    /* offset of 16-color graphics mode */
#define COLOR16A  13	    /* offset of 16-color graphics mode */
#define COLOR256  14


extern int fast;	    /* true if user wants fast mode drawing */

#define TEXT_ONLY     1     /* parms to for_each_mode() */
#define GRAPHICS_ONLY 2
#define ALL_MODES     3

#define hbound(a) (sizeof(a)/sizeof(a[0]))

int error(char *format,...);
void compare_data(int ci, int mi, void *data);
int writestring(BYTE attr,BYTE page,BYTE row,BYTE col,char *format,...);
int pausekey(int nticks);
void for_each_mode(void (*func)(int modeindex), int pausetime, int modes);
void test_mode_support(void);
void set_and_check_curs(CURSINFO set_curs);
void test_cursor_operation(void);
void test_light_pen(void);
void test_multiple_pages(void);
void test_screen_scrolling(void);
void check_text(int mode);
void test_text_io(void);
void check_graphics(int mode);
void test_graphics_io(void);
void test_video_save_restore(void);
void test_palette_functions(void);
void test_character_generator(void);
void test_alternate_select(void);
void test_bios_data(void);
void test_general_regs(void);
void test_dac_regs(void);
void test_sequencer_regs(void);
void test_crtc_regs(void);
void test_graphics_regs(void);
void test_attribute_regs(void);
void usage(void);
int main(int argc,char *argv[]);
